@@ -14,7 +14,8 @@ test_that('efftox_dtps fails when cohort_sizes is not vector of +ve integers', {
                 gamma_mean = 0.7367, gamma_sd = 2.5423,
                 zeta_mean = 3.4181, zeta_sd = 2.4406,
                 eta_mean = 0, eta_sd = 0.2,
-                psi_mean = 0, psi_sd = 1, seed = 123)
+                psi_mean = 0, psi_sd = 1,
+                seed = 123, refresh = 0)
   )
 
   expect_error(
@@ -30,7 +31,8 @@ test_that('efftox_dtps fails when cohort_sizes is not vector of +ve integers', {
                 gamma_mean = 0.7367, gamma_sd = 2.5423,
                 zeta_mean = 3.4181, zeta_sd = 2.4406,
                 eta_mean = 0, eta_sd = 0.2,
-                psi_mean = 0, psi_sd = 1, seed = 123)
+                psi_mean = 0, psi_sd = 1,
+                seed = 123, refresh = 0)
   )
 
   expect_error(
@@ -46,7 +48,8 @@ test_that('efftox_dtps fails when cohort_sizes is not vector of +ve integers', {
                 gamma_mean = 0.7367, gamma_sd = 2.5423,
                 zeta_mean = 3.4181, zeta_sd = 2.4406,
                 eta_mean = 0, eta_sd = 0.2,
-                psi_mean = 0, psi_sd = 1, seed = 123)
+                psi_mean = 0, psi_sd = 1,
+                seed = 123, refresh = 0)
   )
 
   expect_error(
@@ -62,7 +65,8 @@ test_that('efftox_dtps fails when cohort_sizes is not vector of +ve integers', {
                 gamma_mean = 0.7367, gamma_sd = 2.5423,
                 zeta_mean = 3.4181, zeta_sd = 2.4406,
                 eta_mean = 0, eta_sd = 0.2,
-                psi_mean = 0, psi_sd = 1, seed = 123)
+                psi_mean = 0, psi_sd = 1,
+                seed = 123, refresh = 0)
   )
 })
 
@@ -82,7 +86,7 @@ test_that('efftox_dtps and derived tibbles perform as expected.', {
                        zeta_mean = 3.4181, zeta_sd = 2.4406,
                        eta_mean = 0, eta_sd = 0.2,
                        psi_mean = 0, psi_sd = 1,
-                       seed = 123)
+                       seed = 123, refresh = 0)
 
   # Expected number of nodes Here we expect 1 + 4 + 16 = 21 nodes
   expect_equal(length(paths), 21)
